Function lossless_segments

pub fn lossless_segments(project: &Project) -> Option<Vec<(f64, f64)>>
If the project is a pure cut of exactly one video source (every clip from the same asset, audio clips exactly mirroring their linked video clip’s timing on each audio stream (muted tracks may be dropped), no gaps between clips, no text/image/sequence clips, no effects/retime/pan/fades, volume 1, all clips enabled, no transitions, no burnt-in subtitles), return the segments as (src_in, duration) in timeline order. Such a project can be written with -c copy.