Struct Build

struct Build {
    project: Project,
    issues: Vec<Issue>,
    dir: PathBuf,
    missing: Vec<String>,
}

Fields

project: Projectissues: Vec<Issue>dir: PathBufmissing: Vec<String>

Asset paths that could not be found on disk.

Implementations

Source

impl Build

fn new(dir: PathBuf, name: &str) -> Self

fn note( &mut self, level: Level, subject: impl Into<String>, detail: impl Into<String>, )

fn resolve(&mut self, raw: &str, subject: &str) -> String

Existing path for raw (relinked next to the imported file when missing), plus a note.

fn add_asset(&mut self, a: Asset) -> u64

Add an asset, filling the metadata from the real file when it exists.

fn finish(self) -> ImportReport