Function key_for

pub fn key_for(project: &Project, sec: i64) -> u64
Hash of everything that changes the picture during second sec: format, and every clip (with its effects, graph, mask and asset) visible in that second on an active video track.