struct Job {
project: Arc<Project>,
sec: i64,
key: u64,
w: u32,
h: u32,
n: u32,
fps: f64,
generation: u64,
gpu: Option<Sender<GpuFrameRequest>>,
}Expand description
One second of timeline for one worker, against a snapshot of the project it was queued from.
Fields
project: Arc<Project>sec: i64key: u64w: u32h: u32n: u32fps: f64generation: u64gpu: Option<Sender<GpuFrameRequest>>GPU compositor to round-trip frames through, when the renderer was on at request time.