pub fn fragment(kind: EffectKind, user_src: &str) -> Option<String>Expand description
The complete fragment source for one effect, or None when it has no GPU body.
pub fn fragment(kind: EffectKind, user_src: &str) -> Option<String>The complete fragment source for one effect, or None when it has no GPU body.