fn draw_half_size(style: &ShapeStyle) -> (f32, f32)Expand description
Half-size of a drawing: the strokes are relative to the layer centre, so the layer is symmetric.
fn draw_half_size(style: &ShapeStyle) -> (f32, f32)Half-size of a drawing: the strokes are relative to the layer centre, so the layer is symmetric.