pub struct ShapeRasterizer {
cache: HashMap<(u64, u32, u32, u32), Arc<Frame>>,
cov: Vec<f32>,
path: Path,
edges: Vec<Edge>,
active: Vec<usize>,
xs: Vec<(f32, i32)>,
outline: Vec<[f32; 2]>,
}Fields
cache: HashMap<(u64, u32, u32, u32), Arc<Frame>>cov: Vec<f32>Scratch: one coverage buffer, one polygon soup, one edge table, one outline.
path: Pathedges: Vec<Edge>active: Vec<usize>xs: Vec<(f32, i32)>outline: Vec<[f32; 2]>Implementations
Sourceimpl ShapeRasterizer
impl ShapeRasterizer
pub fn new() -> Self
Sourcepub fn size(style: &ShapeStyle, t: f64) -> (f32, f32)
pub fn size(style: &ShapeStyle, t: f64) -> (f32, f32)
Layer size in project px for a style at clip-local time t (before scale).
Sourcepub fn render(&mut self, style: &ShapeStyle, scale: f32, t: f64) -> Arc<Frame>
pub fn render(&mut self, style: &ShapeStyle, scale: f32, t: f64) -> Arc<Frame>
Rasterise at scale (canvas px per project px) for clip-local time t.
fn rasterize( &mut self, style: &ShapeStyle, s: f32, t: f64, lw: u32, lh: u32, bucket: u32, ) -> Frame