struct SharedDeviceManager(IMFDXGIDeviceManager);Expand description
IMFDXGIDeviceManager is documented as safe to share and call from multiple threads (that’s its
purpose: every decoder MFT on every thread opens a handle to the same device through it).
Tuple Fields
0: IMFDXGIDeviceManagerTrait Implementations