pub struct ThumbCache {
shared: Arc<(Mutex<Shared>, Condvar)>,
textures: HashMap<u64, (TextureHandle, [u32; 2])>,
}Fields
textures: HashMap<u64, (TextureHandle, [u32; 2])>egui textures for ready thumbnails, created lazily by texture() (UI thread only).
Implementations
Sourceimpl ThumbCache
impl ThumbCache
pub fn new(ctx: Context, backend: Backend) -> Self
pub fn set_backend(&mut self, b: Backend)
Sourcepub fn get(&mut self, path: &str, t: f64, h: u32) -> Option<Arc<Frame>>
pub fn get(&mut self, path: &str, t: f64, h: u32) -> Option<Arc<Frame>>
Thumbnail frame of path at source time t, h px tall. None while computing (request queued).
Sourcepub fn texture(
&mut self,
ctx: &Context,
path: &str,
t: f64,
h: u32,
) -> Option<(TextureId, [u32; 2])>
pub fn texture( &mut self, ctx: &Context, path: &str, t: f64, h: u32, ) -> Option<(TextureId, [u32; 2])>
Same as get but as an egui texture (created/cached here), with its size in pixels.
pub fn clear(&mut self)