fn fit_view(state: &mut CurvesState, snap: &[Animated], n_props: usize)Expand description
Frame every key of the visible properties on the time axis and reset the value view.
fn fit_view(state: &mut CurvesState, snap: &[Animated], n_props: usize)Frame every key of the visible properties on the time axis and reset the value view.