pub fn take_pending_curve_preset() -> Option<CurvePreset>Expand description
A curve preset captured via “Save curve preset…” waiting for the app to store it in Settings.
pub fn take_pending_curve_preset() -> Option<CurvePreset>A curve preset captured via “Save curve preset…” waiting for the app to store it in Settings.