pub fn set_thumbnail(kind: EffectKind, texture: TextureId, size: [u32; 2])Expand description
The app hands a rendered catalogue thumbnail to the panel (texture must stay alive while shown).
pub fn set_thumbnail(kind: EffectKind, texture: TextureId, size: [u32; 2])The app hands a rendered catalogue thumbnail to the panel (texture must stay alive while shown).