pub fn take_pending_motion() -> Option<MotionPreset>Expand description
A motion preset captured via “Save as motion preset…” waiting for the app to store it in Settings.
pub fn take_pending_motion() -> Option<MotionPreset>A motion preset captured via “Save as motion preset…” waiting for the app to store it in Settings.