Function take_edit_mask

pub fn take_edit_mask() -> Option<u64>
Clip whose mask the user wants to draw in the viewport (“Edit in viewport”) — the app switches the active tool to a mask tool and points the preview at this clip.