Function path_preview

fn path_preview(
    ui: &mut Ui,
    state: &mut LibraryState,
    settings: &mut Settings,
    thumbs: &mut Option<&mut ThumbCache>,
    live: Option<&PreviewFrame>,
    palette: &Palette,
    resp: &mut LibraryResponse,
    path: &str,
)
Preview of a file that is not in the project yet: import it from here, and edit the tags it carries as a recent file (the only place a file outside the project can keep any).