fn reuse_pick(item: &Reuse, name: &str, resp: &mut LibraryResponse)Expand description
What a click on a reusable item asks the app to do.
fn reuse_pick(item: &Reuse, name: &str, resp: &mut LibraryResponse)What a click on a reusable item asks the app to do.