fn transition_node(kind: TransitionKind) -> NodeKindExpand description
The nearest node to a transition: a cross fade / push / wipe is a two-input mix at any one instant, and a dip to colour is that colour.
fn transition_node(kind: TransitionKind) -> NodeKindThe nearest node to a transition: a cross fade / push / wipe is a two-input mix at any one instant, and a dip to colour is that colour.