fn draw_waveform(
p: &Painter,
peaks: &Peaks,
clip: &Clip,
vis: Rect,
state: &TimelineState,
color: Color32,
)Expand description
One vertical min..max line per point column over the visible part of an audio clip.
fn draw_waveform(
p: &Painter,
peaks: &Peaks,
clip: &Clip,
vis: Rect,
state: &TimelineState,
color: Color32,
)One vertical min..max line per point column over the visible part of an audio clip.