pub fn set_stock(tex: TextureHandle)Expand description
The app hands over the picture the effect catalogue renders from; the cards preview over it.
pub fn set_stock(tex: TextureHandle)The app hands over the picture the effect catalogue renders from; the cards preview over it.