fn apply_freeze(
project: &mut Project,
selection: &[u64],
playhead: f64,
undo: &mut dyn FnMut(&Project),
) -> boolExpand description
Freeze only the clips the playhead is actually over: freeze_at stores src_time(playhead), which is
an out-of-range (often negative) source time for a clip elsewhere on the timeline.